/*
  Copyright (C) 2014 Michal Kosciesza <michal@mkiol.net>

  This file is part of Kaktus.

  Kaktus is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  Kaktus is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with Kaktus.  If not, see <http://www.gnu.org/licenses/>.
*/

import QtQuick 2.0
import Sailfish.Silica 1.0
import QtWebKit 3.0

Page {
    id: root

    property bool showBar: false

    property string title
    property string entryId
    property string offlineUrl
    property string onlineUrl
    property bool stared
    property bool read
    property int index
    property int feedindex
    property bool cached
    property int markAsReadTime: 4000

    property bool updateViewPortDone: false
    signal updateViewPort

    ActiveDetector {}

    onForwardNavigationChanged: {
        if (forwardNavigation)
            forwardNavigation = false;
    }

    /*onBackNavigationChanged: {
        if (backNavigation)
            backNavigation = false;
    }*/

    showNavigationIndicator: false

    allowedOrientations: {
        switch (settings.allowedOrientations) {
        case 1:
            return Orientation.Portrait;
        case 2:
            return Orientation.Landscape;
        }
        return Orientation.Landscape | Orientation.Portrait;
    }

    onUpdateViewPort: {
        var viewport = 1;
        if (settings.fontSize==1)
            viewport = 1.5;
        if (settings.fontSize==2)
            viewport = 2.0;
        view.experimental.evaluateJavaScript(
        "(function(){
           var viewport = document.querySelector('meta[name=\"viewport\"]');
           if (viewport) {
             viewport.content = 'initial-scale="+viewport+"';
             return 1;
           }
           document.getElementsByTagName('head')[0].appendChild('<meta name=\"viewport\" content=\"initial-scale="+viewport+"\">');
           return 0;
         })()",
         function(result) {
             //console.log("viewport present:",result);
         });
    }

    SilicaWebView {
        id: view

        anchors { top: parent.top; left: parent.left; right: parent.right; bottom: parent.bottom }

        /*height: {
            if ((dm.busy||fetcher.busy||controlbar.open) && bar.open)
                return isPortrait ? app.height-Theme.itemSizeMedium : app.width-1.6*Theme.itemSizeMedium;
            if (dm.busy||fetcher.busy||controlbar.open)
                return isPortrait ? app.height-Theme.itemSizeMedium : app.width-0.8*Theme.itemSizeMedium;
            if (bar.open)
                return isPortrait ? app.height-Theme.itemSizeMedium : app.width-0.8*Theme.itemSizeMedium;
            return isPortrait ? app.height : app.width;
        }

        Behavior on height {
            enabled: !root.orientationTransitionRunning
            NumberAnimation { duration: 200; easing.type: Easing.InOutQuad }
        }

        clip: true*/

        /*url:  {
            if (settings.offlineMode) {
                if (settings.offlineMode)
                    return offlineUrl+"?width="+view.width+"px"+"&fontsize=24px";
            }
            return onlineUrl;
        }*/

        property int imgWidth: {
            switch (settings.fontSize) {
            case 1:
                return view.width/(1.5);
            case 2:
                return view.width/(2.0);
            }
            return view.width
        }

        url: settings.offlineMode ? offlineUrl+"?fontsize=18px&width="+imgWidth+"px" : onlineUrl

        experimental.userAgent: settings.getDmUserAgent()

        onLoadProgressChanged: {
            // Changing viewport on 50% load proggress in WebView to increase font size
            if (!root.updateViewPortDone &&
                    loadProgress>50 && settings.fontSize>0) {
                root.updateViewPort();
                root.updateViewPortDone = true;
            }
        }

        onLoadingChanged: {

            switch (loadRequest.status) {
            case WebView.LoadStartedStatus:
                proggressPanel.text = qsTr("Loading page content...");
                proggressPanel.open = true;

                // Reseting viewport flag
                root.updateViewPortDone = false;

                break;

            case WebView.LoadSucceededStatus:
                proggressPanel.open = false;

                // Changing viewport in WebView to increase font size
                root.updateViewPort();

                // Start timer to mark as read
                if (!root.read)
                    timer.start();

                break;

            case WebView.LoadFailedStatus:
                proggressPanel.open = false;

                console.log("LoadFailedStatus");

                if (settings.offlineMode)
                    notification.show(qsTr("Failed to load item from local cache :-("));
                else
                    notification.show(qsTr("Failed to load page content :-("));
                break;

            default:
                proggressPanel.open = false;
            }

            /*console.log("-= onLoadingChanged =-");
            console.log(loadRequest.status==WebView.LoadStartedStatus ? "LoadStartedStatus" : loadRequest.status==WebView.LoadFailedStatus ? "LoadFailedStatus" : loadRequest.status==WebView.LoadSucceededStatus ? "LoadSucceededStatus" : "Unknown");
            console.log("loadRequest.url: "+loadRequest.url);
            console.log("loadRequest.status: "+loadRequest.status);
            console.log("loadRequest.errorString: "+loadRequest.errorString);
            console.log("loadRequest.errorCode: "+loadRequest.errorCode);
            console.log("loadRequest.errorDomain: "+loadRequest.errorDomain);*/
        }

        /*onNavigationRequested: {
            // In Off-Line mode navigation is disabled
            if (settings.offlineMode) {
                if (request.url != offlineUrl) {
                    request.action = WebView.IgnoreRequest;
                }
            }
        }*/

        onNavigationRequested: {
            if (!Qt.application.active) {
                request.action = WebView.IgnoreRequest;
            }
        }
    }

    ControlBarWebPreview {
        id: controlbar
        flick: view
        canBack: true
        canStar: true
        canOpenBrowser: true
        stared: root.stared
        transparent: false

        onBackClicked: pageStack.pop()

        onStarClicked: {
            if (stared) {
                stared=false;
                entryModel.setData(root.index, "readlater", 0);
            } else {
                stared=true;
                entryModel.setData(root.index, "readlater", 1);
            }
        }

        onBrowserClicked: {
            notification.show(qsTr("Launching an external browser..."));
            Qt.openUrlExternally(onlineUrl);
        }

        onOfflineClicked: {
            if (settings.offlineMode) {
                if (dm.online)
                    settings.offlineMode = false;
                else
                    notification.show(qsTr("Cannot switch to Online mode.\nNetwork connection is unavailable."));
            } else {
                if (root.cached)
                    settings.offlineMode = true;
                else
                  notification.show(qsTr("Offline version not available."));
            }
        }
    }

    ProgressPanel {
        id: proggressPanel
        transparent: false
        anchors.left: parent.left
        anchors.bottom: parent.bottom
        height: isPortrait ? app.panelHeightPortrait : app.panelHeightLandscape
        cancelable: true
        onCloseClicked: view.stop()
    }

    Timer {
        id: timer
        interval: root.markAsReadTime
        onTriggered: {
            if (!root.read) {
                read=true;
                entryModel.setData(root.index, "read", 1);
            }
        }
    }

    Connections {
        target: fetcher
        onBusyChanged: pageStack.pop()
    }

    Connections {
        target: dm
        onBusyChanged: pageStack.pop()
    }

    // Workaround for 'High Power Consumption' webkit bug
    Connections {
        target: Qt.application
        onActiveChanged: {
            if(!Qt.application.active && settings.powerSaveMode) {
                pageStack.pop();
            }
        }
    }
}
